cmd

package
v0.3.12 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>

SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.

Index

Constants

This section is empty.

Variables

var (
	ErrTooManyArguments        = errors.New("too many arguments: expected one directory path")
	ErrEmptyNamespace          = errors.New("namespace must not be empty")
	ErrPackageAlreadyInstalled = errors.New("package already installed at destination")
)
var ErrInsufficientPackage = errors.New("both package and version must be specified")
var ErrMissingArgument = errors.New("argument must be provided, can be one of [major|minor|patch] or a valid semver")
var ErrNoPackages = errors.New("no packages installed")

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func UpdateFileContent added in v0.3.2

func UpdateFileContent(content *[]byte, versions map[string]Result)

UpdateFileContent updates all typst package import statements in content with the versions provided by the name→version mapping.

Types

type Destination added in v0.3.5

type Destination struct {
	Namespace string
	Name      string
	Version   string
	Path      string
}

type InstallOptions added in v0.3.12

type InstallOptions struct {
	Force     bool
	Editable  bool
	Namespace string
}

InstallOptions holds the resolved install flags.

type Result added in v0.3.10

type Result struct {
	Name    string
	Current string
	Latest  string
}

Directories

Path Synopsis

Jump to