Documentation
¶
Overview ¶
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Copyright © 2026 Nikolas Pikall <nikolas.pikall@gmail.com>
SPDX-License-Identifier: MIT License See the LICENSE file in the repository root for full license text.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Violet = charmtone.Charple Turquoise = lipgloss.Color("86") Magenta = charmtone.Cheeky )
Common Colors
var ( VersionStyle = lipgloss.NewStyle().Foreground(Turquoise).Bold(true) HighStyle = lipgloss.NewStyle().Foreground(Magenta).Bold(true) LogoStyle = lipgloss.NewStyle().Foreground(Violet) DescriptionStyle = lipgloss.NewStyle().Foreground(Magenta) )
Styles for Messages to stdout/stderr
var ErrInsufficientPackage = errors.New("both package and version must be specified")
var ErrMissingArgument = errors.New("argument must be provided, can be one of [major|minor|patch] or a valid semver")
var ErrNoPackages = errors.New("no packages installed")
var GoTPMVersion string
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func UpdateFileContent ¶ added in v0.3.2
Update all typst package import statements in a file, with the values provided by a mapping of package names to the latest version.
Types ¶
This section is empty.